@@ -36,8 +36,8 @@ class AutoStartEdit : public QDialog
     Q_OBJECT
 
 public:
-    explicit AutoStartEdit(QString name, QString command, bool needTray, QWidget* parent = 0);
-    ~AutoStartEdit();
+    explicit AutoStartEdit(QString name, QString command, bool needTray, QWidget* parent = nullptr);
+    ~AutoStartEdit() override;
     QString name();
     QString command();
     bool needTray();
