@@ -40,8 +40,8 @@ class EnvironmentPage : public QWidget
     Q_OBJECT
 
 public:
-    explicit EnvironmentPage(LXQt::Settings *settings, QWidget *parent = 0);
-    ~EnvironmentPage();
+    explicit EnvironmentPage(LXQt::Settings *settings, QWidget *parent = nullptr);
+    ~EnvironmentPage() override;
 
 signals:
     void needRestart();
