@@ -72,8 +72,8 @@ class LXQtModuleManager : public QObject, public QAbstractNativeEventFilter
 
 public:
     //! \brief Construct LXQtModuleManager
-    LXQtModuleManager(QObject* parent = 0);
-    virtual ~LXQtModuleManager();
+    LXQtModuleManager(QObject* parent = nullptr);
+    ~LXQtModuleManager() override;
 
     //! \brief Set the window manager (e.g. "/usr/bin/openbox")
     void setWindowManager(const QString & windowManager);
@@ -91,7 +91,7 @@ public:
     void startup(LXQt::Settings& s);
 
     // Qt5 uses native event filter
-    virtual bool nativeEventFilter(const QByteArray & eventType, void * message, long * result);
+    bool nativeEventFilter(const QByteArray & eventType, void * message, long * result) override;
 
 public slots:
     /*! \brief Exit LXQt session.
@@ -190,7 +190,7 @@ class LXQtModule : public QProcess
 {
     Q_OBJECT
 public:
-    LXQtModule(const XdgDesktopFile& file, QObject *parent = 0);
+    LXQtModule(const XdgDesktopFile& file, QObject *parent = nullptr);
     void start();
     void terminate();
     bool isTerminating();
