@@ -45,7 +45,7 @@ static unsigned int xkb_mask_modifier(Display* /*dpy*/, XkbDescPtr xkb, const ch
         return 0;
     for( i = 0; i < XkbNumVirtualMods; i++ ) {
         char* modStr = XGetAtomName( xkb->dpy, xkb->names->vmods[i] );
-        if( modStr != NULL && strcmp(name, modStr) == 0 ) {
+        if( modStr != nullptr && strcmp(name, modStr) == 0 ) {
             unsigned int mask;
             XkbVirtualModsToReal( xkb, 1 << i, &mask );
             return mask;
@@ -57,7 +57,7 @@ static unsigned int xkb_mask_modifier(Display* /*dpy*/, XkbDescPtr xkb, const ch
 static unsigned int xkb_numlock_mask(Display* dpy)
 {
     XkbDescPtr xkb;
-    if(( xkb = XkbGetKeyboard( dpy, XkbAllComponentsMask, XkbUseCoreKbd )) != NULL ) {
+    if(( xkb = XkbGetKeyboard( dpy, XkbAllComponentsMask, XkbUseCoreKbd )) != nullptr ) {
         unsigned int mask = xkb_mask_modifier( dpy, xkb, "NumLock" );
         XkbFreeKeyboard( xkb, 0, True );
         return mask;
